Learn R Programming

CSIndicators (version 1.2.0)

CST_MaxSpellTimeExceedingThreshold: Maximum spell of a variable exceeding (or not exceeding) a defined Threshold

Description

The maximum number of spell days for a defined threshold during a period. The function accepts daily data and returns the number of maximum spell days exceeding (or not exceeding) the threshold for the defined period. The threshold provided must be in the same units as the variable units, i.e. to use a percentile as a scalar, the function Threshold or QThreshold may be needed.

Usage

CST_MaxSpellTimeExceedingThreshold(
  data,
  threshold,
  op = ">",
  start = NULL,
  end = NULL,
  time_dim = "time",
  na.rm = FALSE,
  ncores = NULL
)

Value

An 's2dv_cube' object containing the maximum number of days that correspond to a spell within a defined threshold, and corresponding to the period defined by the dimensions start and end.

Arguments

data

An 's2dv_cube' object as provided function CST_Start or CST_Load in package CSTools.

threshold

If only one threshold is used, it can be an 's2dv_cube' object or a multidimensional array with named dimensions. It must be in the same units and with the common dimensions of the same length as parameter 'data'. It can also be a vector with the same length of 'time_dim' from 'data' or a scalar. If we want to use two thresholds: it can be a vector of two scalars, a list of two vectors with the same length of 'time_dim' from 'data' or a list of two multidimensional arrays with the common dimensions of the same length as parameter 'data'. If two thresholds are used, parameter 'op' must be also a vector of two elements.

op

An operator '>' (by default), '<', '>=' or '<='. If two thresholds are used, it has to be a vector of a pair of two logical operators: c('<', '>'), c('<', '>='), c('<=', '>'), c('<=', '>='), c('>', '<'), c('>', '<='), c('>=', '<'),c('>=', '<=')).

start

An optional parameter to define the initial date of the period to select from the data by providing a list of two elements: the initial date of the period and the initial month of the period. By default it is set to NULL and the indicator is computed using all the data provided in data.

end

An optional parameter to defined the final date of the period to select from the data by providing a list of two elements: the final day of the period and the final month of the period. By default it is set to NULL and the indicator is computed using all the data provided in data.

time_dim

A character string indicating the name of the dimension to compute the indicator. By default, it is set to 'time'. It can only indicate one time dimension.

na.rm

A logical value indicating whether to ignore NA values (TRUE) or not (FALSE).

ncores

An integer indicating the number of cores to use in parallel computation.

Examples

Run this code
exp <- NULL
exp$data <- array(rnorm(5 * 3 * 214 * 2)*23,
                 c(member = 5, sdate = 3, time = 214, lon = 2)) 
exp$attrs$Dates <- c(seq(as.Date("01-05-2000", format = "%d-%m-%Y"), 
                        as.Date("30-11-2000", format = "%d-%m-%Y"), by = 'day'),
                    seq(as.Date("01-05-2001", format = "%d-%m-%Y"), 
                        as.Date("30-11-2001", format = "%d-%m-%Y"), by = 'day'),
                    seq(as.Date("01-05-2002", format = "%d-%m-%Y"), 
                        as.Date("30-11-2002", format = "%d-%m-%Y"), by = 'day'))
dim(exp$attrs$Dates) <- c(sdate = 3, time = 214)
class(exp) <- 's2dv_cube'
TTSET <- CST_MaxSpellTimeExceedingThreshold(exp, threshold = 23, op = '>',
                                           start = list(21, 4), 
                                           end = list(21, 6))

Run the code above in your browser using DataLab